==> nio-bot-1.0.0.tar.gz: nio-bot-1.0.0/src/niobot/utils/unblocking.py <==
import asyncio
import typing
import functools
from typing import Any


__all__ = ("run_blocking", "force_await")


async def run_blocking(function: typing.Callable, *args: Any, **kwargs: Any) -> Any:
    """
    Takes a blocking function and runs it in a thread, returning the result.

    You should use this for any long-running functions that may take a long time to respond that are not coroutines
    that you can await. For example, running a subprocess.

    ??? note "Example"
        ```py
        import asyncio
        import subprocess
        from niobot.utils import run_blocking

        async def main():
            result = await run_blocking(subprocess.run, ["find", "*.py", "-type", "f"], capture_output=True)
            print(result)

        asyncio.run(main())
        ```

    :param function: The function to call. Make sure you do not call it, just pass it.
    :param args: The arguments to pass to the function.
    :param kwargs: The keyword arguments to pass to the function.
    :returns: The result of the function.
    """
    obj = functools.partial(function, *args, **kwargs)
    loop = asyncio.get_running_loop()
    return await loop.run_in_executor(None, obj)


async def force_await(function: typing.Union[typing.Callable, typing.Coroutine], *args: Any, **kwargs: Any):
    """
    Takes a function, and if it needs awaiting, it will be awaited.
    If it is a synchronous function, it runs it in the event loop, preventing it from blocking.

    This is equivalent to (pseudo):
    ```py
    if can_await(x):
        await x
    else:
        await run_blocking(x)
    ```

    :param function: The function to call. Make sure you do not call it, just pass it.
    :param args: The arguments to pass to the function.
    :param kwargs: The keyword arguments to pass to the function.
    :returns: The result of the function.
    """
    if asyncio.iscoroutinefunction(function) or asyncio.iscoroutine(function):
        return await function(*args, **kwargs)
    else:
        return await run_blocking(function, *args, **kwargs)

==> nio-bot-1.1.0a2.tar.gz: nio-bot-1.1.0a2/src/niobot/utils/unblocking.py <==
import asyncio
import functools
import typing
from typing import Any

__all__ = ("run_blocking", "force_await")


async def run_blocking(function: typing.Callable, *args: Any, **kwargs: Any) -> Any:
    """
    Takes a blocking function and runs it in a thread, returning the result.

    You should use this for any long-running functions that may take a long time to respond that are not coroutines
    that you can await. For example, running a subprocess.

    ??? example
        ```py
        import asyncio
        import subprocess
        from niobot.utils import run_blocking

        async def main():
            result = await run_blocking(subprocess.run, ["find", "*.py", "-type", "f"], capture_output=True)
            print(result)

        asyncio.run(main())
        ```

    :param function: The function to call. Make sure you do not call it, just pass it.
    :param args: The arguments to pass to the function.
    :param kwargs: The keyword arguments to pass to the function.
    :returns: The result of the function.
    """
    obj = functools.partial(function, *args, **kwargs)
    loop = asyncio.get_running_loop()
    return await loop.run_in_executor(None, obj)


async def force_await(function: typing.Union[typing.Callable, typing.Coroutine], *args: Any, **kwargs: Any):
    """
    Takes a function, and if it needs awaiting, it will be awaited.
    If it is a synchronous function, it runs it in the event loop, preventing it from blocking.

    This is equivalent to (pseudo):
    ```py
    if can_await(x):
        await x
    else:
        await run_blocking(x)
    ```

    :param function: The function to call. Make sure you do not call it, just pass it.
    :param args: The arguments to pass to the function.
    :param kwargs: The keyword arguments to pass to the function.
    :returns: The result of the function.
    """
    if asyncio.iscoroutinefunction(function):
        return await function(*args, **kwargs)
    elif asyncio.iscoroutine(function):
        return await function
    else:
        return await run_blocking(function, *args, **kwargs)
